@@ -1,38 +1,60 @@
 #' Function to query allofus observation table for survey responses
 #'
-#' @description
-#' Because responses to the survey questions stored in the ds_survey table do not
-#' include skipped questions (i.e., missing data!), this function makes it easier to
-#' query the observation table for responses to survey questions so that the skipped
-#' responses are included.
+#' @description Extracts survey responses in a tidy format that also includes
+#'   ‘skip’ responses and collapses across all versions of the person health /
+#'   personal medical history surveys. Currently responses in the ‘ds_survey’
+#'   table omit skipped responses. Responses are returned as Yes" if the
+#'   respondent answered that the individual had the condition, No" if the
+#'   respondent answered that the individual did not have that condition (or
+#'   omitted it when selecting from related conditions), a skip response if the
+#'   question was skipped, and NA if the respondent did not answer the question.
+#'   Returns a data frame or SQL tbl with the initial cohort table along with a
+#'   column for each question included in questions and answers foreach
+#'   person_id in the cells. To find the desired survey questions, use the all
+#'   of us data dictionary, survey codebook, Athena, data browser, or the
+#'   modified codebook which can be found in the allofus R package.
 #'
-#' The function will return a dataframe or SQL tbl with the initial cohort table along
-#' with a column for each question included in `questions` and answers for
-#' each person_id in the cells. The column names (questions) can
-#' be returned as the concept_code or concept_id or by providing new column names. For each question, a column with
-#' the suffix "_date" is included with the date on which the question was answered.
-#' When questions can have multiple answers ("checkbox"-style questions), answers
-#' are returned as a comma-separated string.
+#' @details The function will return a dataframe or SQL tbl with the initial
+#'   cohort table along with a column for each question included in `questions`
+#'   and answers for each person_id in the cells. The column names (questions)
+#'   can be returned as the concept_code or concept_id or by providing new
+#'   column names. For each question, a column with the suffix "_date" is
+#'   included with the date on which the question was answered. When questions
+#'   can have multiple answers ("checkbox"-style questions), answers are
+#'   returned as a comma-separated string.
 #'
-#' To find the desired survey questions, use the all of us data dictionary,
-#' survey codebook, athena, data browser, or the allofus R package
-#' modified codebook which can be found here: https://roux-ohdsi.github.io/allofus/articles/searchable_codebook.html
-#' For questions regarding an individual's health history or family health history,
-#' the function requires the specific concept_id (or concept_code) for individual in question,
-#' whether that is "self" or another relative. Responses are returned as "Yes" if the respondent
-#' answered that the individual had the condition, "No" if the respondent answered that the individual
-#' did not have that condition (or omitted it when selecting from related conditions), a
-#' skip response if the question was skipped, and NA if the respondent did not answer the question.
+#'   To find the desired survey questions, use the all of us data dictionary,
+#'   survey codebook, athena, data browser, or the allofus R package modified
+#'   codebook which can be found here:
+#'   https://roux-ohdsi.github.io/allofus/articles/searchable_codebook.html For
+#'   questions regarding an individual's health history or family health
+#'   history, the function requires the specific concept_id (or concept_code)
+#'   for individual in question, whether that is "self" or another relative.
+#'   Responses are returned as "Yes" if the respondent answered that the
+#'   individual had the condition, "No" if the respondent answered that the
+#'   individual did not have that condition (or omitted it when selecting from
+#'   related conditions), a skip response if the question was skipped, and NA if
+#'   the respondent did not answer the question.
 #'
-#' @param cohort tbl or dataframe with a cohort that includes a column called person_id
-#' @param questions either a vector of concept_ids or concept_codes for questions to return results
-#' @param question_output how to name the columns. Options include as the text of the concept code ("concept_code"), as concept ids preceded by
-#' "x_" ("concept_id"), or using a custom vector of column names matching the vector of `questions`. Defaults to "concept_code".
-#' @param clean_answers whether to clean the answers to the survey questions. Defaults to TRUE.
-#' @param con connection to the allofus SQL database. Defaults to getOption("aou.default.con"), which is created automatically with `aou_connect()`
-#' @param collect whether to return the results as a local (TRUE) or database table
+#' @param cohort Reference to a remote table or local dataframe with a column
+#'   called "person_id"
+#' @param questions either a vector of concept_ids or concept_codes for
+#'   questions to return results
+#' @param question_output how to name the columns. Options include as the text
+#'   of the concept code ("concept_code"), as concept ids preceded by "x_"
+#'   ("concept_id"), or using a custom vector of column names matching the
+#'   vector of `questions`. Defaults to "concept_code".
+#' @param clean_answers whether to clean the answers to the survey questions.
+#'   Defaults to TRUE.
+#' @param con connection to the allofus SQL database. Defaults to
+#'   getOption("aou.default.con"), which is created automatically with
+#'   `aou_connect()`
+#' @param collect Whether to bring the resulting table into local memory
+#'   (`collect = TRUE`) as a dataframe or leave as a reference to a database
+#'   table (for continued analysis using, e.g., `dbplyr`). Defaults to `FALSE.`
 #' @param ... additional arguments passed to `collect()` when `collect = TRUE`
-#' @return a dataframe if collect = TRUE; a remote tbl if not
+#' @return A dataframe if `collect = TRUE`; a reference to a remote database
+#'   table if not.
 #' @export
 #' @examplesIf on_workbench()
 #'
@@ -68,23 +90,9 @@ aou_survey <- function(cohort = NULL,
                        questions,
                        question_output = "concept_code",
                        clean_answers = TRUE,
-                       con = getOption("aou.default.con"),
                        collect = FALSE,
-                       ...) {
-  if (packageVersion("dbplyr") < "2.3.0") {
-    stop('
-          Older versions of dbplyr are not supported by the aou_survey() function.
-          Please install either v2.3.4 or the development version of dbplyr.
-          note: v.2.4.0 is not compatible with the AllofUS Database
-          # Install {pak}
-          install.packages("pak")
-          # Install dbplyr v2.3.4
-          pak::pkg_install("tidyverse/dbplyr@v2.3.4")
-          # Or install development version of dbplyr
-          pak::pkg_install("tidyverse/dbplyr")
-          # restart your R kernel')
-  }
-
+                       ...,
+                       con = getOption("aou.default.con")) {
   # check for connection
   if (is.null(con)) {
     cli::cli_abort(c("No connection available.",
@@ -94,10 +102,8 @@ aou_survey <- function(cohort = NULL,
   }
 
   # check for NA values or empty strings in questions or question_output
-  if(any(is.na(c(questions, question_output))) | any(c(questions, question_output) == "")){
+  if (any(is.na(c(questions, question_output))) | any(c(questions, question_output) == "")) {
     cli::cli_abort("NA values or empty string detected in {.code questions} or {.code question_output}")
-  } else {
-    print("works")
   }
 
   if (length(question_output) == length(questions)) { # either gave column names or happen to have a single question
@@ -142,7 +148,7 @@ aou_survey <- function(cohort = NULL,
       dplyr::select("person_id")
   } else {
     function_cohort <- cohort %>%
-      dplyr::select("person_id")
+      dplyr::distinct(.data$person_id)
   }
 
   # pivot longer to inclde the rx, on_txt, and age_diagnosis columns
@@ -382,7 +388,8 @@ aou_survey <- function(cohort = NULL,
         dplyr::group_by(.data$person_id) %>%
         dplyr::slice_max(order_by = type, n = 1) %>%
         dplyr::ungroup() %>%
-        dplyr::select("person_id", !!condition_name := "condition", !!condition_date := "observation_date")
+        dplyr::select("person_id", !!condition_name := "condition", !!condition_date := "observation_date") %>%
+        aou_compute()
     }) %>%
       purrr::reduce(dplyr::left_join, by = "person_id")
 
@@ -402,7 +409,8 @@ aou_survey <- function(cohort = NULL,
     tmp <- dplyr::tbl(con, "observation") %>%
       dplyr::filter(.data$observation_source_concept_id %in% regular_survey_concept_ids) %>%
       # this is necessary because there may be multiple rows for a single person (hence full_join later)
-      dplyr::inner_join(dplyr::select(function_cohort, "person_id"), by = "person_id")
+      dplyr::inner_join(dplyr::select(function_cohort, "person_id"), by = "person_id") %>%
+      aou_compute()
 
     # for retrieving columns and pivoting
     q <- paste0("observation_source_", question_output)
@@ -461,7 +469,8 @@ aou_survey <- function(cohort = NULL,
       # change to lower, then rename
       wide <- wide %>%
         dplyr::rename_with(tolower) %>%
-        dplyr::rename(dplyr::all_of(nm))
+        dplyr::rename(dplyr::all_of(nm)) %>%
+        aou_compute()
     }
     # join back to original table
     out <- dplyr::full_join(cohort_w_health, wide, by = "person_id")
