@@ -19,6 +19,10 @@ NULL
 #' Check if a value is a date
 #' @keywords internal
 #' @noRd
-is.date <- function(x){
- inherits(x, 'Date')
+is.date <- function(x) {
+  inherits(x, "Date")
 }
+
+# fix for between CRAN error from
+# https://dplyr.tidyverse.org/articles/in-packages.html#join-helpers
+utils::globalVariables("between")
