@@ -12,11 +12,11 @@ test_that("aou_connect returns an error message when unable to connect", {
   expect_error(aou_connect(CDR = "nonexistent.dataset"))
 })
 
-test_that("aou_sql returns a dataframe", {
+test_that("aou_sql returns a dataframe when collect = TRUE", {
   skip_workbench()
 
   query <- "SELECT * FROM `{CDR}.person` LIMIT 10"
-  result <- aou_sql(query)
+  result <- aou_sql(query, collect = TRUE)
   expect_is(result, "data.frame")
 })
 
@@ -25,6 +25,6 @@ test_that("aou_sql correctly evaluates references to `CDR` when specified", {
   skip_workbench()
 
   query <- "SELECT COUNT(*) FROM `{CDR}.person`"
-  result <- aou_sql(query, CDR = paste0(Sys.getenv("WORKSPACE_CDR"), "_base"))
+  result <- aou_sql(query, collect = TRUE, CDR = paste0(Sys.getenv("WORKSPACE_CDR"), "_base"))
   expect_true(result > 0)
 })
